.cookie-monster{left:0;bottom:0;width:100%;font-family:Helvetica Neue,Helvetica,Arial,sans-serif;padding:16px}.cookie-monster .cookie-monster--content,.cookie-monster .cookie-monster--title{max-width:780px;margin:0 auto}.cookie-monster .cookie-monster--btn{padding:8px 16px;border:none;font-size:1rem;background:#fff;cursor:pointer;border-radius:4px;font-weight:600;}.cookie-monster .cookie-monster--btn:focus{background:#e6e6e9}.cookie-monster .cookie-monster--btn:hover{background:#e6e6e9}.cookie-monster .cookie-monster--btn-group{display:-webkit-box;display:flex;-webkit-box-pack:end;justify-content:flex-end;margin:calc(8px*-1)}.cookie-monster .cookie-monster--table{margin:16px;width:100%;table-layout:fixed}.cookie-monster .cookie-monster--table-cell{padding:4px 0}.cookie-monster .cookie-monster--group-description{margin:0}.cookie-monster .cookie-monster--group-title{display:-webkit-box;display:flex;-webkit-box-align:center;align-items:center;-webkit-box-pack:justify;justify-content:space-between;cursor:pointer}.cookie-monster .cookie-monster--btn-wrapper{padding:8px}.cookie-monster .cookie-monster--btn.cookie-monster--btn__active{background:#9999a1}.cookie-monster .cookie-monster--btn.cookie-monster--btn__accordion{width:100%;text-align:left}.cookie-monster .cookie-monster--btn.cookie-monster--btn__toggle{font-weight:400}.cookie-monster .cookie-monster--btn.cookie-monster--btn__accept-all{background:#e1e1e1;}.cookie-monster .cookie-monster--btn.cookie-monster--btn__accept-all:focus,.cookie-monster .cookie-monster--btn.cookie-monster--btn__accept-all:hover{background:var(--accept-button-background-hover-color)}.cookie-monster .cookie-monster--btn.cookie-monster--btn__confirm{background:#e1e1e1;}.cookie-monster .cookie-monster--btn.cookie-monster--btn__confirm:focus,.cookie-monster .cookie-monster--btn.cookie-monster--btn__confirm:hover{background:var(--accept-button-background-hover-color)}